# -*- coding: utf-8 -*-
#
# Copyright (C) 2006-2007 Edgewall Software
# All rights reserved.
#
# This software is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at http://posterity.edgewall.org/wiki/License.
#
# This software consists of voluntary contributions made by many
# individuals. For the exact contribution history, see the revision
# history and logs, available at http://posterity.edgewall.org/log/.

from gettext import find as find_catalog
import os

from babel import Locale
from babel.support import Translations
from paste.registry import StackedObjectProxy
import pkg_resources

from posterity import config

locale = StackedObjectProxy()
gettext = StackedObjectProxy(lambda x: x)
ngettext = StackedObjectProxy(lambda x, y: x)
_ = gettext

def gettext_noop(msg):
    return msg
N_ = gettext_noop

def setup_i18n(request):
    default_locale = config.get('posterity', 'default_locale', 'en_US')
    locale_dir = pkg_resources.resource_filename('posterity', 'locale')
    available = [dirname.replace('_', '-') for dirname
                 in os.listdir(locale_dir) if '.' not in dirname]
    l = Locale.negotiate(request.languages, available, sep='-')
    if l is None:
        l = Locale.parse(default_locale)
    translations = Translations.load(locale_dir, l)
    request.environ['paste.registry'].register(gettext, translations.ugettext)
    request.environ['paste.registry'].register(ngettext, translations.ungettext)
    request.environ['paste.registry'].register(locale, l)
